// Copyright 2019 github.com. All rights reserved.
// Use of this source code is governed by github.com.

package v1

import (
	"smart-supplier-management-gateway/param/base"
	"smart-supplier-management-gateway/pb/v1"
)


type DeviceTypeAddBody struct {
	ProviderId int64 `form:"provider_id" json:"provider_id"`
	// 设备类型
	DeviceType int32 `form:"device_type" json:"device_type"`
	// 备注
	Comment string `form:"comment" json:"comment"`
	// 经办人
	Agent string `form:"agent" json:"agent"`
	// 经办人电话
	AgentPhone string `form:"agent_phone" json:"agent_phone"`
	// 诚信经营承诺书
	Appendix           []string `form:"appendix" json:"appendix"`
}

type DeviceTypeAddRequest struct {
	base.Header
	DeviceTypeAddBody
}

type DeviceTypeAddResponse struct {
	base.Result
	Data v1.DeviceTypeAddReply `json:"data"`
}


type DeviceTypeTestingAddBody struct {
	ProviderId int64 `form:"provider_id" json:"provider_id"`
	// 设备类型
	DeviceType int32 `form:"device_type" json:"device_type"`
	// 备注
	Comment string `form:"comment" json:"comment"`
	// 经办人
	Agent string `form:"agent" json:"agent"`
	// 经办人电话
	AgentPhone string `form:"agent_phone" json:"agent_phone"`
	//
	Appendix           []string `form:"appendix" json:"appendix"`
}

type DeviceTypeTestingAddRequest struct {
	base.Header
	DeviceTypeTestingAddBody
}

type DeviceTypeTestingAddResponse struct {
	base.Result
	Data v1.DeviceTypeTestingAddReply `json:"data"`
}

type DeviceAddBody struct {
	ProjectId int64   `json:"project_id" form:"project_id"`
	Name   string  `json:"name" form:"name"`
	Sn     string  `json:"sn" form:"sn"`
	Lon    float32 `json:"lon" form:"lon"`
	Lat    float32 `json:"lat" form:"lat"`
	ProjectCode string  `form:"project_code" json:"project_code"`
	ProjectName string  `form:"project_name" json:"project_name"`
	// 设备型号
	DeviceModel string `form:"device_model" json:"device_model"`
	// 生产厂商
	Manufacturer string `form:"manufacturer" json:"manufacturer"`
	// 批次
	Batch string `form:"batch" json:"batch"`
	// 对接单位
	Unit string `form:"unit" json:"unit"`
	// 联系人
	Person string `form:"person" json:"person"`
	// 联系电话
	Phone string `form:"phone" json:"phone"`
	// 备注
	Remark string `form:"remark" json:"remark"`
	// url视屏地址 仅扬尘有
	Url                  string   `form:"url" json:"url"`

	Kind int32 `form:"kind" json:"kind"`
	SubKind int32 `form:"sub_kind" json:"sub_kind"`
}

type DeviceAddRequest struct {
	base.Header
	DeviceAddBody
}

type DeviceAddResponse struct {
	base.Result
	Data v1.DeviceAddReply `json:"data"`
}

type DeviceDelBody struct {
	Id int64 `form:"id"`
	Reason string `form:"reason"`
}

type DeviceDelRequest struct {
	base.Header
	DeviceDelBody
}

type DeviceDelResponse struct {
	base.Result
}

type DeviceTypeListQuery struct {
	ListType uint32 `form:"list_type" json:"list_type"`
	DeviceCode int32 `form:"device_code" json:"device_code"`
}

type DeviceTypeListRequest struct {
	base.Header
	DeviceTypeListQuery
}

type DeviceTypeListResponse struct {
	base.Result
	Data []*v1.DeviceTypeItem `json:"data"`
}

type DeviceListQuery struct {
	// 审核状态 0 待审核 1 通过 2 未通过
	FilterStatus string `form:"filter_status"`
	ProjectId int64 `form:"project_id"`
	Filter string `form:"filter"`
	Page int32 `form:"page"`
}

type DeviceListRequest struct {
	base.Header
	DeviceListQuery
}

type DeviceListResponse struct {
	base.Result
	Data v1.DeviceListReply `json:"data"`
}

type DeviceDelJobListQuery struct {
	Page int32 `form:"page"`
	// 审核状态 0 待审核 1 通过 2 未通过
	FilterStatus string `form:"filter_status"`
	Filter string `form:"filter"`
}

type DeviceDelJobListRequest struct {
	base.Header
	DeviceDelJobListQuery
}

type DeviceDelJobListResponse struct {
	base.Result
	Data v1.DeviceDelJobListReply `json:"data"`
}


type ProjectListRequest struct {
	base.Header
}

type ProjectListResponse struct {
	base.Result
	Data []*v1.ProjectItem `json:"data"`
}

type ChannelAddBody struct {
	Sn string `form:"sn"`
	ChannelCount int32 `form:"channel_count"`
}

type ChannelAddRequest struct {
	base.Header
	ChannelAddBody
}

type ChannelAddResponse struct {
	base.Result
}

type ChannelListQuery struct {
	Sn string `form:"sn"`
	ChannelNo string `form:"channel_no"`
	Page int32 `form:"page"`
}

type ChannelListRequest struct {
	base.Header
	ChannelListQuery
}

type ChannelListResponse struct {
	base.Result
	Data v1.ChannelListReply `json:"data"`
}

type ChannelUpdateBody struct {
	Id int64 `form:"id"`
	Name string `form:"name"`
}

type ChannelUpdateRequest struct {
	base.Header
	ChannelUpdateBody
}

type ChannelUpdateResponse struct {
	base.Result
}

type VedioAddBody struct {
	ProjectId int64 `form:"project_id"`
	VedioType int32 `form:"vedio_type"`
	Name string `form:"name"`
	ChannelCount int32 `form:"channel_count"`
}

type VedioAddRequest struct {
	base.Header
	VedioAddBody
}

type VedioAddResponse struct {
	base.Result
	Data v1.VedioAddReply `json:"data"`
}

type VedioListQuery struct {
	// 审核状态 0 待审核 1 通过 2 未通过
	FilterStatus string `form:"filter_status"`
	ProjectId int64 `form:"project_id"`
	Filter string `form:"filter"`
	Page int32 `form:"page"`
}

type VedioListRequest struct {
	base.Header
	VedioListQuery
}

type VedioListResponse struct {
	base.Result
	Data v1.VedioListReply `json:"data"`
}

type DeviceAllTypeListResponse struct {
	base.Result
	Data v1.DeviceTypeListReply `json:"data"`
}
